#!/bin/sh

PREFIX=@PREFIX@

GQUILT_LIB_DIR=$PREFIX/share/gquilt
export GQUILT_LIB_DIR

GQUILT_ICON=$PREFIX/share/pixmaps/gquilt.xpm
export GQUILT_ICON

PYTHONPATH=$PYTHONPATH:$GQUILT_LIB_DIR
export PYTHONPATH

exec python $GQUILT_LIB_DIR/gquilt.py
